@@ -1,10 +1,12 @@
 import re
+import log
 
 def cors(response, code):
     return response, code, { "Access-Control-Allow-Origin": "*"}
 
 class RequestHandler:
-    def __init__(self):
+    def __init__(self, debug=True):
+        self.debug = debug
         self.endpoints = {}
 
     def add(self, cls, endpoint):
@@ -44,6 +46,9 @@ class RequestHandler:
         return "", []
 
     def handle(self, request):
+        if self.debug:
+            log.request(request)
+
         path = request.path
         route, params = self._match_route(path)
 
@@ -60,4 +65,7 @@ class RequestHandler:
         if request.method.lower() == "options":
             return http_verb_handler(endpoint_handler)
 
-        return cors(*http_verb_handler(endpoint_handler))
+        response = cors(*http_verb_handler(endpoint_handler))
+        log.response(response)
+
+        return response
